"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

var _sortModuleFileExtension = _interopRequireDefault(require("./sortModuleFileExtension"));

var _isTypeImport = _interopRequireDefault(require("./isTypeImport"));

var _moduleFileType = require("./moduleFileType");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _default(styleApi) {
  const {
    and,
    isAbsoluteModule,
    isRelativeModule,
    moduleName,
    member,
    name,
    not,
    unicode
  } = styleApi;
  return [//
  // Importing absolute modules, js files.
  // ex:
  // import "foo"
  // import * as Foo from "foo"
  // import _ from "foo"
  {
    match: and(not(_isTypeImport.default), isAbsoluteModule, _moduleFileType.isJsFile),
    sort: moduleName(unicode),
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }, //
  // Importing absolute modules, ts files.
  // ex:
  // import "foo"
  // import Foo from "foo.ts"
  // import Foo from "foo.tsx"
  {
    match: and(not(_isTypeImport.default), isAbsoluteModule, _moduleFileType.isTsFile),
    sort: moduleName(unicode),
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }, //
  // Importing absolute modules, style files.
  // ex:
  // import "foo.css"
  // import css from "foo.css"
  // import scss from "foo.scss"
  // import less from "foo.less"
  {
    match: and(not(_isTypeImport.default), isAbsoluteModule, _moduleFileType.isStyleFile),
    sort: [(0, _sortModuleFileExtension.default)(unicode), moduleName(unicode)],
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }, //
  // Importing absolute modules, any other file types.
  // ex:
  // import "foo.svg"
  // import img from "foo.png"
  // import txt from "foo.text"
  {
    match: and(not(_isTypeImport.default), isAbsoluteModule),
    sort: [(0, _sortModuleFileExtension.default)(unicode), moduleName(unicode)],
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }, //
  // importing types from absolute modules files
  // ex:
  // import type foo from "foo"
  {
    match: and(_isTypeImport.default, isAbsoluteModule),
    sort: moduleName(unicode),
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }, //
  // Importing relative modules, js files.
  // ex:
  // import "../foo"
  // import * as Foo from "../foo"
  // import _ from "../foo"
  {
    match: and(not(_isTypeImport.default), isRelativeModule, _moduleFileType.isJsFile),
    sort: moduleName(unicode),
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }, //
  // Importing relative modules, ts files.
  // ex:
  // import "../foo.ts"
  // import Foo from "../foo.tsx"
  // import Foo from "../foo.ts"
  {
    match: and(not(_isTypeImport.default), isRelativeModule, _moduleFileType.isTsFile),
    sort: moduleName(unicode),
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }, //
  // Importing relative modules, style files.
  // ex:
  // import "../foo.css"
  // import css from "../foo.css"
  // import scss from "../foo.scss"
  // import less from "../foo.less"
  {
    match: and(not(_isTypeImport.default), isRelativeModule, _moduleFileType.isStyleFile),
    sort: [(0, _sortModuleFileExtension.default)(unicode), moduleName(unicode)],
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }, //
  // Importing absolute modules, any other file types.
  // ex:
  // import "../foo.svg"
  // import img from "../foo.png"
  // import txt from "../foo.text"
  {
    match: and(not(_isTypeImport.default), isRelativeModule),
    sort: [(0, _sortModuleFileExtension.default)(unicode), moduleName(unicode)],
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }, //
  // importing types from relative modules files
  // ex:
  // import type foo from "../foo"
  {
    match: and(_isTypeImport.default, isRelativeModule),
    sort: member(unicode),
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }];
}